/**
 * a class for storing a move on a Queens game
 *
 * @version	$Id: Move.java,v 1.4 2003/02/19 15:16:57 nthiery Exp $
 * @author	Nicolas M. Thiry <nthiery@users.sourceforge.net>
**/

public class Move {
    /**
     * (xpos[0],ypos[0]) are the coordinates of the starting point of the
     * move, and so on, until (xpos[xpos.length-1], ypos[ypos.length-1])
     * which are the coordinates of the final position.
     **/
    public int [] xpos;
    public int [] ypos;

    /**
     * Constructor for a simple move without intermediate positions
     *
     * @param x1, y1, x2, y2	positive integers
     **/
    public Move(int x1, int y1, int x2, int y2) {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Constructor for a complex move with intermediate positions
     *
     * @param x, y	arrays of positive integers
     **/
    public Move(int [] x, int [] y) {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Constructor for a complex move from a string such as "A2-C4-A6"
     *
     * @param move	a string
     **/
    public Move(String move) {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Convert a move into a string such as "A2-C4-A6"
     *
     * @param
     * @return a string
     **/
    public String toString() {
	// Note: the examples in AsciiDemo might help to implement this method
	throw new RuntimeException("Not Implemented");
    }
}
